@@ -3,7 +3,7 @@
 # Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)
 
 PROG="`basename $0`"
-HOSTNAME="`hostname`"
+ICINGA2HOST="`hostname`"
 MAILBIN="mail"
 
 if [ -z "`which $MAILBIN`" ] ; then
@@ -16,7 +16,6 @@ Usage() {
 cat << EOF
 
 Required parameters:
-  -4 HOSTADDRESS (\$address\$)
   -d LONGDATETIME (\$icinga.long_date_time\$)
   -e SERVICENAME (\$service.name\$)
   -l HOSTNAME (\$host.name\$)
@@ -28,6 +27,7 @@ Required parameters:
   -u SERVICEDISPLAYNAME (\$service.display_name\$)
 
 Optional parameters:
+  -4 HOSTADDRESS (\$address\$)
   -6 HOSTADDRESS6 (\$address6\$)
   -b NOTIFICATIONAUTHORNAME (\$notification.author\$)
   -c NOTIFICATIONCOMMENT (\$notification.comment\$)
@@ -55,7 +55,7 @@ Error() {
 while getopts 4:6:b:c:d:e:f:hi:l:n:o:r:s:t:u:v: opt
 do
   case "$opt" in
-    4) HOSTADDRESS=$OPTARG ;; # required
+    4) HOSTADDRESS=$OPTARG ;;
     6) HOSTADDRESS6=$OPTARG ;;
     b) NOTIFICATIONAUTHORNAME=$OPTARG ;;
     c) NOTIFICATIONCOMMENT=$OPTARG ;;
@@ -85,7 +85,7 @@ shift $((OPTIND - 1))
 
 ## Check required parameters (TODO: better error message)
 ## Keep formatting in sync with mail-host-notification.sh
-if [ ! "$HOSTADDRESS" ] || [ ! "$LONGDATETIME" ] \
+if [ ! "$LONGDATETIME" ] \
 || [ ! "$HOSTNAME" ] || [ ! "$HOSTDISPLAYNAME" ] \
 || [ ! "$SERVICENAME" ] || [ ! "$SERVICEDISPLAYNAME" ] \
 || [ ! "$SERVICEOUTPUT" ] || [ ! "$SERVICESTATE" ] \
@@ -98,19 +98,24 @@ SUBJECT="[$NOTIFICATIONTYPE] $SERVICEDISPLAYNAME on $HOSTDISPLAYNAME is $SERVICE
 
 ## Build the notification message
 NOTIFICATION_MESSAGE=`cat << EOF
-***** Icinga 2 Service Monitoring on $HOSTNAME *****
+***** Service Monitoring on $ICINGA2HOST *****
 
-==> $SERVICEDISPLAYNAME on $HOSTDISPLAYNAME is $SERVICESTATE! <==
+$SERVICEDISPLAYNAME on $HOSTDISPLAYNAME is $SERVICESTATE!
 
 Info:    $SERVICEOUTPUT
 
 When:    $LONGDATETIME
-Service: $SERVICENAME (Display Name: "$SERVICEDISPLAYNAME")
-Host:    $HOSTNAME (Display Name: "$HOSTDISPLAYNAME")
-IPv4:    $HOSTADDRESS
+Service: $SERVICENAME
+Host:    $HOSTNAME
 EOF
 `
 
+## Check whether IPv4 was specified.
+if [ -n "$HOSTADDRESS" ] ; then
+  NOTIFICATION_MESSAGE="$NOTIFICATION_MESSAGE
+IPv4:    $HOSTADDRESS"
+fi
+
 ## Check whether IPv6 was specified.
 if [ -n "$HOSTADDRESS6" ] ; then
   NOTIFICATION_MESSAGE="$NOTIFICATION_MESSAGE
@@ -129,8 +134,7 @@ fi
 if [ -n "$ICINGAWEB2URL" ] ; then
   NOTIFICATION_MESSAGE="$NOTIFICATION_MESSAGE
 
-URL:
-  $ICINGAWEB2URL/monitoring/service/show?host=$HOSTNAME&service=$SERVICENAME"
+$ICINGAWEB2URL/monitoring/service/show?host=$HOSTNAME&service=$SERVICENAME"
 fi
 
 ## Check whether verbose mode was enabled and log to syslog.
