@@ -246,11 +246,11 @@ static int InstallIcinga(void)
 
 		MkDirP(dataDir + "/etc/icinga2/pki");
 		MkDirP(dataDir + "/var/cache/icinga2");
-		MkDirP(dataDir + "/var/lib/icinga2/pki");
+		MkDirP(dataDir + "/var/lib/icinga2/certs");
+		MkDirP(dataDir + "/var/lib/icinga2/certificate-requests");
 		MkDirP(dataDir + "/var/lib/icinga2/agent/inventory");
 		MkDirP(dataDir + "/var/lib/icinga2/api/config");
 		MkDirP(dataDir + "/var/lib/icinga2/api/log");
-		MkDirP(dataDir + "/var/lib/icinga2/api/repository");
 		MkDirP(dataDir + "/var/lib/icinga2/api/zones");
 		MkDirP(dataDir + "/var/log/icinga2/compat/archive");
 		MkDirP(dataDir + "/var/log/icinga2/crash");
