@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -207,6 +207,43 @@ static Array::Ptr ArrayFilter(const Function::Ptr& function)
 	return result;
 }
 
+static bool ArrayAny(const Function::Ptr& function)
+{
+	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
+	Array::Ptr self = static_cast<Array::Ptr>(vframe->Self);
+
+	if (vframe->Sandboxed && !function->IsSideEffectFree())
+		BOOST_THROW_EXCEPTION(ScriptError("Filter function must be side-effect free."));
+
+	ObjectLock olock(self);
+	for (const Value& item : self) {
+		std::vector<Value> args;
+		args.push_back(item);
+		if (function->Invoke(args))
+			return true;
+	}
+
+	return false;
+}
+
+static bool ArrayAll(const Function::Ptr& function)
+{
+	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
+	Array::Ptr self = static_cast<Array::Ptr>(vframe->Self);
+
+	if (vframe->Sandboxed && !function->IsSideEffectFree())
+		BOOST_THROW_EXCEPTION(ScriptError("Filter function must be side-effect free."));
+
+	ObjectLock olock(self);
+	for (const Value& item : self) {
+		std::vector<Value> args;
+		args.push_back(item);
+		if (!function->Invoke(args))
+			return false;
+	}
+
+	return true;
+}
 static Array::Ptr ArrayUnique(void)
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
@@ -228,21 +265,23 @@ Object::Ptr Array::GetPrototype(void)
 
 	if (!prototype) {
 		prototype = new Dictionary();
-		prototype->Set("len", new Function("Array#len", WrapFunction(ArrayLen), true));
-		prototype->Set("set", new Function("Array#set", WrapFunction(ArraySet)));
-		prototype->Set("get", new Function("Array#get", WrapFunction(ArrayGet)));
-		prototype->Set("add", new Function("Array#add", WrapFunction(ArrayAdd)));
-		prototype->Set("remove", new Function("Array#remove", WrapFunction(ArrayRemove)));
-		prototype->Set("contains", new Function("Array#contains", WrapFunction(ArrayContains), true));
+		prototype->Set("len", new Function("Array#len", WrapFunction(ArrayLen), {}, true));
+		prototype->Set("set", new Function("Array#set", WrapFunction(ArraySet), { "index", "value" }));
+		prototype->Set("get", new Function("Array#get", WrapFunction(ArrayGet), { "index" }));
+		prototype->Set("add", new Function("Array#add", WrapFunction(ArrayAdd), { "value" }));
+		prototype->Set("remove", new Function("Array#remove", WrapFunction(ArrayRemove), { "index" }));
+		prototype->Set("contains", new Function("Array#contains", WrapFunction(ArrayContains), { "value" }, true));
 		prototype->Set("clear", new Function("Array#clear", WrapFunction(ArrayClear)));
-		prototype->Set("sort", new Function("Array#sort", WrapFunction(ArraySort), true));
-		prototype->Set("shallow_clone", new Function("Array#shallow_clone", WrapFunction(ArrayShallowClone), true));
-		prototype->Set("join", new Function("Array#join", WrapFunction(ArrayJoin), true));
-		prototype->Set("reverse", new Function("Array#reverse", WrapFunction(ArrayReverse), true));
-		prototype->Set("map", new Function("Array#map", WrapFunction(ArrayMap), true));
-		prototype->Set("reduce", new Function("Array#reduce", WrapFunction(ArrayReduce), true));
-		prototype->Set("filter", new Function("Array#filter", WrapFunction(ArrayFilter), true));
-		prototype->Set("unique", new Function("Array#unique", WrapFunction(ArrayUnique), true));
+		prototype->Set("sort", new Function("Array#sort", WrapFunction(ArraySort), { "less_cmp" }, true));
+		prototype->Set("shallow_clone", new Function("Array#shallow_clone", WrapFunction(ArrayShallowClone), {}, true));
+		prototype->Set("join", new Function("Array#join", WrapFunction(ArrayJoin), { "separator" }, true));
+		prototype->Set("reverse", new Function("Array#reverse", WrapFunction(ArrayReverse), {}, true));
+		prototype->Set("map", new Function("Array#map", WrapFunction(ArrayMap), { "func" }, true));
+		prototype->Set("reduce", new Function("Array#reduce", WrapFunction(ArrayReduce), { "reduce" }, true));
+		prototype->Set("filter", new Function("Array#filter", WrapFunction(ArrayFilter), { "func" }, true));
+		prototype->Set("any", new Function("Array#any", WrapFunction(ArrayAny), { "func" }, true));
+		prototype->Set("all", new Function("Array#all", WrapFunction(ArrayAll), { "func" }, true));
+		prototype->Set("unique", new Function("Array#unique", WrapFunction(ArrayUnique), {}, true));
 	}
 
 	return prototype;
