@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -374,6 +374,14 @@ void ConfigObject::Start(bool runtimeCreated)
 	SetStartCalled(true);
 }
 
+void ConfigObject::PreActivate(void)
+{
+	CONTEXT("Setting 'active' to true for object '" + GetName() + "' of type '" + GetReflectionType()->GetName() + "'");
+
+	ASSERT(!IsActive());
+	SetActive(true, true);
+}
+
 void ConfigObject::Activate(bool runtimeCreated)
 {
 	CONTEXT("Activating object '" + GetName() + "' of type '" + GetReflectionType()->GetName() + "'");
@@ -384,8 +392,6 @@ void ConfigObject::Activate(bool runtimeCreated)
 		Start(runtimeCreated);
 
 		ASSERT(GetStartCalled());
-		ASSERT(!IsActive());
-		SetActive(true, true);
 
 		if (GetHAMode() == HARunEverywhere)
 			SetAuthority(true);
@@ -710,5 +716,18 @@ ConfigObject::Ptr ConfigObject::GetZone(void) const
 	return m_Zone;
 }
 
+Dictionary::Ptr ConfigObject::GetSourceLocation(void) const
+{
+	DebugInfo di = GetDebugInfo();
+
+	Dictionary::Ptr result = new Dictionary();
+	result->Set("path", di.Path);
+	result->Set("first_line", di.FirstLine);
+	result->Set("first_column", di.FirstColumn);
+	result->Set("last_line", di.LastLine);
+	result->Set("last_column", di.LastColumn);
+	return result;
+}
+
 NameComposer::~NameComposer(void)
 { }
