@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -262,6 +262,8 @@ const std::vector<String>& ConfigWriter::GetKeywords(void)
 		keywords.push_back("else");
 		keywords.push_back("while");
 		keywords.push_back("throw");
+		keywords.push_back("try");
+		keywords.push_back("except");
 	}
 
 	return keywords;
