@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -19,18 +19,21 @@
 
 #include "base/function.hpp"
 #include "base/function.tcpp"
+#include "base/array.hpp"
 #include "base/scriptframe.hpp"
 
 using namespace icinga;
 
 REGISTER_TYPE_WITH_PROTOTYPE(Function, Function::GetPrototype());
 
-Function::Function(const String& name, const Callback& function, bool side_effect_free, bool deprecated)
+Function::Function(const String& name, const Callback& function, const std::vector<String>& args,
+    bool side_effect_free, bool deprecated)
 	: m_Callback(function)
 {
 	SetName(name, true);
 	SetSideEffectFree(side_effect_free, true);
 	SetDeprecated(deprecated, true);
+	SetArguments(Array::FromVector(args), true);
 }
 
 Value Function::Invoke(const std::vector<Value>& arguments)
