@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -43,7 +43,8 @@ public:
 
 	typedef boost::function<Value (const std::vector<Value>& arguments)> Callback;
 
-	Function(const String& name, const Callback& function, bool side_effect_free = false, bool deprecated = false);
+	Function(const String& name, const Callback& function, const std::vector<String>& args = std::vector<String>(),
+	    bool side_effect_free = false, bool deprecated = false);
 
 	Value Invoke(const std::vector<Value>& arguments = std::vector<Value>());
 	Value Invoke(const Value& otherThis, const std::vector<Value>& arguments = std::vector<Value>());
@@ -66,47 +67,47 @@ private:
 	Callback m_Callback;
 };
 
-#define REGISTER_SCRIPTFUNCTION_NS(ns, name, callback) \
+#define REGISTER_SCRIPTFUNCTION_NS(ns, name, callback, args) \
 	INITIALIZE_ONCE_WITH_PRIORITY([]() { \
-		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), false); \
+		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), String(args).Split(":"), false); \
 		ScriptGlobal::Set(#ns "." #name, sf); \
 	}, 10)
 
-#define REGISTER_SCRIPTFUNCTION_NS_PREFIX(ns, name, callback) \
+#define REGISTER_SCRIPTFUNCTION_NS_PREFIX(ns, name, callback, args) \
 	INITIALIZE_ONCE_WITH_PRIORITY([]() { \
-		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), false); \
+		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), String(args).Split(":"), false); \
 		ScriptGlobal::Set(#ns "." #name, sf); \
-		Function::Ptr dsf = new icinga::Function("Deprecated#__" #name " (deprecated)", WrapFunction(callback), false, true); \
+		Function::Ptr dsf = new icinga::Function("Deprecated#__" #name " (deprecated)", WrapFunction(callback), String(args).Split(":"), false, true); \
 		ScriptGlobal::Set("Deprecated.__" #name, dsf); \
 	}, 10)
 
-#define REGISTER_SCRIPTFUNCTION_NS_DEPRECATED(ns, name, callback) \
+#define REGISTER_SCRIPTFUNCTION_NS_DEPRECATED(ns, name, callback, args) \
 	INITIALIZE_ONCE_WITH_PRIORITY([]() { \
-		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), false); \
+		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), String(args).Split(":"), false); \
 		ScriptGlobal::Set(#ns "." #name, sf); \
-		Function::Ptr dsf = new icinga::Function("Deprecated#" #name " (deprecated)", WrapFunction(callback), false, true); \
+		Function::Ptr dsf = new icinga::Function("Deprecated#" #name " (deprecated)", WrapFunction(callback), String(args).Split(":"), false, true); \
 		ScriptGlobal::Set("Deprecated." #name, dsf); \
 	}, 10)
 
-#define REGISTER_SAFE_SCRIPTFUNCTION_NS(ns, name, callback) \
+#define REGISTER_SAFE_SCRIPTFUNCTION_NS(ns, name, callback, args) \
 	INITIALIZE_ONCE_WITH_PRIORITY([]() { \
-		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), true); \
+		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), String(args).Split(":"), true); \
 		ScriptGlobal::Set(#ns "." #name, sf); \
 	}, 10)
 
-#define REGISTER_SAFE_SCRIPTFUNCTION_NS_PREFIX(ns, name, callback) \
+#define REGISTER_SAFE_SCRIPTFUNCTION_NS_PREFIX(ns, name, callback, args) \
 	INITIALIZE_ONCE_WITH_PRIORITY([]() { \
-		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), true); \
+		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), String(args).Split(":"), true); \
 		ScriptGlobal::Set(#ns "." #name, sf); \
-		Function::Ptr dsf = new icinga::Function("Deprecated#__" #name " (deprecated)", WrapFunction(callback), true, true); \
+		Function::Ptr dsf = new icinga::Function("Deprecated#__" #name " (deprecated)", WrapFunction(callback), String(args).Split(":"), true, true); \
 		ScriptGlobal::Set("Deprecated.__" #name, dsf); \
 	}, 10)
 
-#define REGISTER_SAFE_SCRIPTFUNCTION_NS_DEPRECATED(ns, name, callback) \
+#define REGISTER_SAFE_SCRIPTFUNCTION_NS_DEPRECATED(ns, name, callback, args) \
 	INITIALIZE_ONCE_WITH_PRIORITY([]() { \
-		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), true); \
+		Function::Ptr sf = new icinga::Function(#ns "#" #name, WrapFunction(callback), String(args).Split(":"), true); \
 		ScriptGlobal::Set(#ns "." #name, sf); \
-		Function::Ptr dsf = new icinga::Function("Deprecated#" #name " (deprecated)", WrapFunction(callback), true, true); \
+		Function::Ptr dsf = new icinga::Function("Deprecated#" #name " (deprecated)", WrapFunction(callback), String(args).Split(":"), true, true); \
 		ScriptGlobal::Set("Deprecated." #name, dsf); \
 	}, 10)
 
