@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -52,9 +52,9 @@ Object::Ptr Object::GetPrototype(void)
 
 	if (!prototype) {
 		prototype = new Dictionary();
-		prototype->Set("to_string", new Function("Object#to_string", WrapFunction(ObjectToString), true));
-		prototype->Set("notify_attribute", new Function("Object#notify_attribute", WrapFunction(ObjectNotifyAttribute), false));
-		prototype->Set("clone", new Function("Object#clone", WrapFunction(ObjectClone), true));
+		prototype->Set("to_string", new Function("Object#to_string", WrapFunction(ObjectToString), {}, true));
+		prototype->Set("notify_attribute", new Function("Object#notify_attribute", WrapFunction(ObjectNotifyAttribute), { "attribute" }, false));
+		prototype->Set("clone", new Function("Object#clone", WrapFunction(ObjectClone), {}, true));
 	}
 
 	return prototype;
