@@ -35,6 +35,7 @@
 #ifndef _WIN32
 #	include <execvpe.h>
 #	include <poll.h>
+#	include <string.h>
 
 #	ifndef __APPLE__
 extern char **environ;
@@ -137,11 +138,10 @@ static Value ProcessSpawnImpl(struct msghdr *msgh, const Dictionary::Ptr& reques
 
 	pid_t pid = fork();
 
-	if (pid < 0) {
-		BOOST_THROW_EXCEPTION(posix_error()
-			<< boost::errinfo_api_function("fork")
-			<< boost::errinfo_errno(errno));
-	}
+	int errorCode = 0;
+
+	if (pid < 0)
+		errorCode = errno;
 
 	if (pid == 0) {
 		// child process
@@ -163,8 +163,8 @@ static Value ProcessSpawnImpl(struct msghdr *msgh, const Dictionary::Ptr& reques
 		(void)close(fds[2]);
 
 #ifdef HAVE_NICE
-		if (adjustPriority && nice(5) < 0)
-			Log(LogWarning, "base", "Failed to renice child process.");
+		if (adjustPriority)
+			nice(5);
 #endif /* HAVE_NICE */
 
 		sigset_t mask;
@@ -202,6 +202,8 @@ static Value ProcessSpawnImpl(struct msghdr *msgh, const Dictionary::Ptr& reques
 
 	Dictionary::Ptr response = new Dictionary();
 	response->Set("rc", pid);
+	if (errorCode)
+		response->Set("errno", errorCode);
 	return response;
 }
 
@@ -210,10 +212,12 @@ static Value ProcessKillImpl(struct msghdr *msgh, const Dictionary::Ptr& request
 	pid_t pid = request->Get("pid");
 	int signum = request->Get("signum");
 
-	int rc = kill(pid, signum);
+	errno = 0;
+	kill(pid, signum);
+	int error = errno;
 
 	Dictionary::Ptr response = new Dictionary();
-	response->Set("rc", rc);
+	response->Set("errno", error);
 
 	return response;
 }
@@ -415,12 +419,16 @@ send_message:
 
 	ssize_t rc = recv(l_ProcessControlFD, buf, sizeof(buf), 0);
 
-	if (rc < 0)
+	if (rc <= 0)
 		return -1;
 
 	String jresponse = String(buf, buf + rc);
 
 	Dictionary::Ptr response = JsonDecode(jresponse);
+
+	if (response->Get("rc") == -1)
+		errno = response->Get("errno");
+
 	return response->Get("rc");
 }
 
@@ -447,13 +455,13 @@ send_message:
 
 	ssize_t rc = recv(l_ProcessControlFD, buf, sizeof(buf), 0);
 
-	if (rc < 0)
+	if (rc <= 0)
 		return -1;
 
 	String jresponse = String(buf, buf + rc);
 
 	Dictionary::Ptr response = JsonDecode(jresponse);
-	return response->Get("rc");
+	return response->Get("errno");
 }
 
 static int ProcessWaitPID(pid_t pid, int *status)
@@ -478,7 +486,7 @@ send_message:
 
 	ssize_t rc = recv(l_ProcessControlFD, buf, sizeof(buf), 0);
 
-	if (rc < 0)
+	if (rc <= 0)
 		return -1;
 
 	String jresponse = String(buf, buf + rc);
@@ -975,6 +983,11 @@ void Process::Run(const boost::function<void(const ProcessResult&)>& callback)
 	m_Process = ProcessSpawn(m_Arguments, m_ExtraEnvironment, m_AdjustPriority, fds);
 	m_PID = m_Process;
 
+	if (m_PID == -1) {
+		m_OutputStream << "Fork failed with error code " << errno << " (" << Utility::FormatErrorNumber(errno) << ")";
+		Log(LogCritical, "Process", m_OutputStream.str());
+	}
+
 	Log(LogNotice, "Process")
 	    << "Running command " << PrettyPrintArguments(m_Arguments) << ": PID " << m_PID;
 
@@ -1008,6 +1021,9 @@ void Process::Run(const boost::function<void(const ProcessResult&)>& callback)
 bool Process::DoEvents(void)
 {
 	bool is_timeout = false;
+#ifndef _WIN32
+	bool could_not_kill = false;
+#endif /* _WIN32 */
 
 	if (m_Timeout != 0) {
 		double timeout = m_Result.ExecutionStart + m_Timeout;
@@ -1021,7 +1037,13 @@ bool Process::DoEvents(void)
 #ifdef _WIN32
 			TerminateProcess(m_Process, 1);
 #else /* _WIN32 */
-			ProcessKill(-m_Process, SIGKILL);
+			int error = ProcessKill(-m_Process, SIGKILL);
+			if (error) {
+				Log(LogWarning, "Process")
+				    << "Couldn't kill the process group " << m_PID << " (" << PrettyPrintArguments(m_Arguments)
+				    << "): [errno " << error << "] " << strerror(error);
+				could_not_kill = true;
+			}
 #endif /* _WIN32 */
 
 			is_timeout = true;
@@ -1067,7 +1089,9 @@ bool Process::DoEvents(void)
 	    << "PID " << m_PID << " (" << PrettyPrintArguments(m_Arguments) << ") terminated with exit code " << exitcode;
 #else /* _WIN32 */
 	int status, exitcode;
-	if (ProcessWaitPID(m_Process, &status) != m_Process) {
+	if (could_not_kill || m_PID == -1) {
+		exitcode = 128;
+	} else if (ProcessWaitPID(m_Process, &status) != m_Process) {
 		exitcode = 128;
 
 		Log(LogWarning, "Process")
