@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -145,17 +145,17 @@ Object::Ptr String::GetPrototype(void)
 
 	if (!prototype) {
 		prototype = new Dictionary();
-		prototype->Set("len", new Function("String#len", WrapFunction(StringLen), true));
-		prototype->Set("to_string", new Function("String#to_string", WrapFunction(StringToString), true));
-		prototype->Set("substr", new Function("String#substr", WrapFunction(StringSubstr), true));
-		prototype->Set("upper", new Function("String#upper", WrapFunction(StringUpper), true));
-		prototype->Set("lower", new Function("String#lower", WrapFunction(StringLower), true));
-		prototype->Set("split", new Function("String#split", WrapFunction(StringSplit), true));
-		prototype->Set("find", new Function("String#find", WrapFunction(StringFind), true));
-		prototype->Set("contains", new Function("String#contains", WrapFunction(StringContains), true));
-		prototype->Set("replace", new Function("String#replace", WrapFunction(StringReplace), true));
-		prototype->Set("reverse", new Function("String#reverse", WrapFunction(StringReverse), true));
-		prototype->Set("trim", new Function("String#trim", WrapFunction(StringTrim), true));
+		prototype->Set("len", new Function("String#len", WrapFunction(StringLen), {}, true));
+		prototype->Set("to_string", new Function("String#to_string", WrapFunction(StringToString), {}, true));
+		prototype->Set("substr", new Function("String#substr", WrapFunction(StringSubstr), { "start", "len" }, true));
+		prototype->Set("upper", new Function("String#upper", WrapFunction(StringUpper), {}, true));
+		prototype->Set("lower", new Function("String#lower", WrapFunction(StringLower), {}, true));
+		prototype->Set("split", new Function("String#split", WrapFunction(StringSplit), { "delims" }, true));
+		prototype->Set("find", new Function("String#find", WrapFunction(StringFind), { "str", "start" }, true));
+		prototype->Set("contains", new Function("String#contains", WrapFunction(StringContains), { "str" }, true));
+		prototype->Set("replace", new Function("String#replace", WrapFunction(StringReplace), { "search", "replacement" }, true));
+		prototype->Set("reverse", new Function("String#reverse", WrapFunction(StringReverse), {}, true));
+		prototype->Set("trim", new Function("String#trim", WrapFunction(StringTrim), {}, true));
 	}
 
 	return prototype;
