@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -24,6 +24,7 @@
 #include "base/object.hpp"
 #include <boost/algorithm/string/case_conv.hpp>
 #include <boost/algorithm/string/trim.hpp>
+#include <boost/algorithm/string/split.hpp>
 #include <boost/range/iterator.hpp>
 #include <string.h>
 #include <functional>
@@ -238,6 +239,13 @@ public:
 		return m_Data.substr(first, len);
 	}
 
+	inline std::vector<String> Split(const char *separators) const
+	{
+		std::vector<String> result;
+		boost::algorithm::split(result, m_Data, boost::is_any_of(separators));
+		return result;
+	}
+
 	inline void Replace(SizeType first, SizeType second, const String& str)
 	{
 		m_Data.replace(first, second, str);
