@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -22,6 +22,7 @@
 
 #include "base/i2-base.hpp"
 #include "base/timer.hpp"
+#include "base/ringbuffer.hpp"
 #include <boost/function.hpp>
 #include <boost/thread/thread.hpp>
 #include <boost/thread/mutex.hpp>
@@ -93,6 +94,7 @@ public:
 	bool IsWorkerThread(void) const;
 
 	size_t GetLength(void) const;
+	int GetTaskCount(RingBuffer::SizeType span) const;
 
 	void SetExceptionCallback(const ExceptionCallback& callback);
 
@@ -100,6 +102,9 @@ public:
 	std::vector<boost::exception_ptr> GetExceptions(void) const;
 	void ReportExceptions(const String& facility) const;
 
+protected:
+	void IncreaseTaskCount(void);
+
 private:
 	int m_ID;
 	String m_Name;
@@ -120,6 +125,12 @@ private:
 	ExceptionCallback m_ExceptionCallback;
 	std::vector<boost::exception_ptr> m_Exceptions;
 	Timer::Ptr m_StatusTimer;
+	double m_StatusTimerTimeout;
+
+	mutable boost::mutex m_StatsMutex;
+	RingBuffer m_TaskStats;
+	int m_PendingTasks;
+	double m_PendingTasksTimestamp;
 
 	void WorkerThreadProc(void);
 	void StatusTimerHandler(void);
