@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -21,11 +21,11 @@
 #include "checker/checkercomponent.tcpp"
 #include "icinga/icingaapplication.hpp"
 #include "icinga/cib.hpp"
-#include "icinga/perfdatavalue.hpp"
 #include "remote/apilistener.hpp"
 #include "base/configtype.hpp"
 #include "base/objectlock.hpp"
 #include "base/utility.hpp"
+#include "base/perfdatavalue.hpp"
 #include "base/logger.hpp"
 #include "base/exception.hpp"
 #include "base/convert.hpp"
@@ -75,6 +75,10 @@ void CheckerComponent::Start(bool runtimeCreated)
 {
 	ObjectImpl<CheckerComponent>::Start(runtimeCreated);
 
+	Log(LogInformation, "CheckerComponent")
+	    << "'" << GetName() << "' started.";
+
+
 	m_Thread = boost::thread(boost::bind(&CheckerComponent::CheckThreadProc, this));
 
 	m_ResultTimer = new Timer();
@@ -85,7 +89,8 @@ void CheckerComponent::Start(bool runtimeCreated)
 
 void CheckerComponent::Stop(bool runtimeRemoved)
 {
-	Log(LogInformation, "CheckerComponent", "Checker stopped.");
+	Log(LogInformation, "CheckerComponent")
+	    << "'" << GetName() << "' stopped.";
 
 	{
 		boost::mutex::scoped_lock lock(m_Mutex);
