@@ -106,11 +106,16 @@ bool DaemonUtility::ValidateConfigFiles(const std::vector<std::string>& configs,
 
 	if (!configs.empty()) {
 		for (const String& configPath : configs) {
-			Expression *expression = ConfigCompiler::CompileFile(configPath, String(), "_etc");
-			success = ExecuteExpression(expression);
-			delete expression;
-			if (!success)
-				return false;
+			try {
+				Expression *expression = ConfigCompiler::CompileFile(configPath, String(), "_etc");
+				success = ExecuteExpression(expression);
+				delete expression;
+				if (!success)
+					return false;
+			} catch (const std::exception& ex) {
+				Log(LogCritical, "cli", "Could not compile config files: " + DiagnosticInformation(ex, false));
+				Application::Exit(1);
+			}
 		}
 	}
 
@@ -178,7 +183,13 @@ bool DaemonUtility::LoadConfigFiles(const std::vector<std::string>& configs,
 	}
 
 	ConfigCompilerContext::GetInstance()->FinishObjectsFile();
-	ScriptGlobal::WriteToFile(varsfile);
+
+	try {
+		ScriptGlobal::WriteToFile(varsfile);
+	} catch (const std::exception& ex) {
+		Log(LogCritical, "cli", "Could not write vars file: " + DiagnosticInformation(ex, false));
+		Application::Exit(1);
+	}
 
 	return true;
 }
