@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -146,9 +146,8 @@ int FeatureUtility::DisableFeatures(const std::vector<std::string>& features)
 		String target = features_enabled_dir + "/" + feature + ".conf";
 
 		if (!Utility::PathExists(target) ) {
-			Log(LogCritical, "cli")
-			    << "Cannot disable feature '" << feature << "'. Target file '" << target << "' does not exist.";
-			errors.push_back(feature);
+			Log(LogWarning, "cli")
+			    << "Feature '" << feature << "' already disabled.";
 			continue;
 		}
 
