@@ -40,6 +40,12 @@ public:
 	virtual int GetMaxArguments(void) const override;
 	virtual int Run(const boost::program_options::variables_map& vm, const std::vector<std::string>& ap) const override;
 	virtual ImpersonationLevel GetImpersonationLevel(void) const override;
+	virtual void InitParameters(boost::program_options::options_description& visibleDesc,
+	    boost::program_options::options_description& hiddenDesc) const override;
+
+private:
+	int ClientSetup(void) const;
+	int MasterSetup(void) const;
 };
 
 }
