@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -135,7 +135,7 @@ Expression *ConfigCompiler::HandleInclude(const String& relativeBase, const Stri
 {
 	String upath;
 
-	if (search || (path.GetLength() > 0 && path[0] == '/'))
+	if (search || (IsAbsolutePath(path)))
 		upath = path;
 	else
 		upath = relativeBase + "/" + path;
@@ -179,7 +179,7 @@ Expression *ConfigCompiler::HandleIncludeRecursive(const String& relativeBase, c
 {
 	String ppath;
 
-	if (path.GetLength() > 0 && path[0] == '/')
+	if (IsAbsolutePath(path))
 		ppath = path;
 	else
 		ppath = relativeBase + "/" + path;
@@ -198,7 +198,7 @@ void ConfigCompiler::HandleIncludeZone(const String& relativeBase, const String&
 
 	String ppath;
 
-	if (path.GetLength() > 0 && path[0] == '/')
+	if (IsAbsolutePath(path))
 		ppath = path;
 	else
 		ppath = relativeBase + "/" + path;
@@ -223,7 +223,7 @@ Expression *ConfigCompiler::HandleIncludeZones(const String& relativeBase, const
 	String ppath;
 	String newRelativeBase = relativeBase;
 
-	if (path.GetLength() > 0 && path[0] == '/')
+	if (IsAbsolutePath(path))
 		ppath = path;
 	else {
 		ppath = relativeBase + "/" + path;
@@ -351,3 +351,13 @@ bool ConfigCompiler::HasZoneConfigAuthority(const String& zoneName)
 	return !empty;
 }
 
+
+bool ConfigCompiler::IsAbsolutePath(const String& path)
+{
+#ifndef _WIN32
+	return (path.GetLength() > 0 && path[0] == '/');
+#else /* _WIN32 */
+	return !PathIsRelative(path.CStr());
+#endif /* _WIN32 */
+}
+
