@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -888,7 +888,7 @@ private:
 class I2_CONFIG_API ObjectExpression : public DebuggableExpression
 {
 public:
-	ObjectExpression(bool abstract, const String& type, Expression *name, Expression *filter,
+	ObjectExpression(bool abstract, Expression *type, Expression *name, Expression *filter,
 	    const String& zone, const String& package, std::map<String, Expression *> *closedVars,
 	    bool defaultTmpl, bool ignoreOnError, Expression *expression, const DebugInfo& debugInfo = DebugInfo())
 		: DebuggableExpression(debugInfo), m_Abstract(abstract), m_Type(type),
@@ -915,7 +915,7 @@ protected:
 
 private:
 	bool m_Abstract;
-	String m_Type;
+	Expression *m_Type;
 	Expression *m_Name;
 	boost::shared_ptr<Expression> m_Filter;
 	String m_Zone;
@@ -1027,6 +1027,27 @@ private:
 	Expression *m_Name;
 };
 
+class I2_CONFIG_API TryExceptExpression : public DebuggableExpression
+{
+public:
+	TryExceptExpression(Expression *tryBody, Expression *exceptBody, const DebugInfo& debugInfo = DebugInfo())
+		: DebuggableExpression(debugInfo), m_TryBody(tryBody), m_ExceptBody(exceptBody)
+	{ }
+
+	~TryExceptExpression(void)
+	{
+		delete m_TryBody;
+		delete m_ExceptBody;
+	}
+
+protected:
+	virtual ExpressionResult DoEvaluate(ScriptFrame& frame, DebugHint *dhint) const override;
+
+private:
+	Expression *m_TryBody;
+	Expression *m_ExceptBody;
+};
+
 }
 
 #endif /* EXPRESSION_H */
