@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -93,3 +93,8 @@ Value DbValue::GetValue(void) const
 {
 	return m_Value;
 }
+
+void DbValue::SetValue(const Value& value)
+{
+	m_Value = value;
+}
