@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -46,7 +46,7 @@ public:
 
 	static void AcknowledgementSetHandler(const Checkable::Ptr& checkable,
 	    const String& author, const String& comment, AcknowledgementType type,
-	    bool notify, double expiry, const MessageOrigin::Ptr& origin);
+	    bool notify, bool persistent, double expiry, const MessageOrigin::Ptr& origin);
 	static void AcknowledgementClearedHandler(const Checkable::Ptr& checkable, const MessageOrigin::Ptr& origin);
 
 	static void CommentAddedHandler(const Comment::Ptr& comment);
