@@ -315,14 +315,11 @@ void Checkable::ProcessCheckResult(const CheckResult::Ptr& cr, const MessageOrig
 	olock.Lock();
 	SetLastCheckResult(cr);
 
-	bool was_flapping, is_flapping;
+	bool was_flapping = IsFlapping();
 
-	was_flapping = IsFlapping();
+	UpdateFlappingStatus(old_state != cr->GetState());
 
-	if (GetStateType() == StateTypeHard)
-		UpdateFlappingStatus(stateChange);
-
-	is_flapping = IsFlapping();
+	bool is_flapping = IsFlapping();
 
 	if (cr->GetActive()) {
 		UpdateNextCheck(origin);
@@ -335,12 +332,15 @@ void Checkable::ProcessCheckResult(const CheckResult::Ptr& cr, const MessageOrig
 
 	olock.Unlock();
 
-//	Log(LogDebug, "Checkable")
-//	    << "Flapping: Checkable " << GetName()
-//	    << " was: " << (was_flapping)
-//	    << " is: " << is_flapping)
-//	    << " threshold: " << GetFlappingThreshold()
-//	    << "% current: " + GetFlappingCurrent()) << "%.";
+#ifdef I2_DEBUG /* I2_DEBUG */
+	Log(LogDebug, "Checkable")
+	    << "Flapping: Checkable " << GetName()
+	    << " was: " << was_flapping
+	    << " is: " << is_flapping
+	    << " threshold low: " << GetFlappingThresholdLow()
+	    << " threshold high: " << GetFlappingThresholdHigh()
+	    << "% current: " << GetFlappingCurrent() << "%.";
+#endif /* I2_DEBUG */
 
 	OnNewCheckResult(this, cr, origin);
 
@@ -354,13 +354,13 @@ void Checkable::ProcessCheckResult(const CheckResult::Ptr& cr, const MessageOrig
 	if (hardChange || (is_volatile && !(IsStateOK(old_state) && IsStateOK(new_state)))) {
 		OnStateChange(this, cr, StateTypeHard, origin);
 		Log(LogNotice, "Checkable")
-		    << "State Change: Checkable " << GetName() << " hard state change from " << old_state_str << " to " << new_state_str << " detected." << (is_volatile ? " Checkable is volatile." : "");
+		    << "State Change: Checkable '" << GetName() << "' hard state change from " << old_state_str << " to " << new_state_str << " detected." << (is_volatile ? " Checkable is volatile." : "");
 	}
 	/* Whether a state change happened or the state type is SOFT (must be logged too). */
 	else if (stateChange || GetStateType() == StateTypeSoft) {
 		OnStateChange(this, cr, StateTypeSoft, origin);
 		Log(LogNotice, "Checkable")
-		    << "State Change: Checkable " << GetName() << " soft state change from " << old_state_str << " to " << new_state_str << " detected.";
+		    << "State Change: Checkable '" << GetName() << "' soft state change from " << old_state_str << " to " << new_state_str << " detected.";
 	}
 
 	if (GetStateType() == StateTypeSoft || hardChange || recovery ||
@@ -368,13 +368,14 @@ void Checkable::ProcessCheckResult(const CheckResult::Ptr& cr, const MessageOrig
 		ExecuteEventHandler();
 
 	/* Flapping start/end notifications */
-	if (send_notification && !was_flapping && is_flapping) {
+	if (!in_downtime && !was_flapping && is_flapping) {
 		/* FlappingStart notifications happen on state changes, not in downtimes */
 		if (!IsPaused())
 			OnNotificationsRequested(this, NotificationFlappingStart, cr, "", "", MessageOrigin::Ptr());
 
 		Log(LogNotice, "Checkable")
-			<< "Flapping: Checkable " << GetName() << " started flapping (" << GetFlappingThreshold() << "% < " << GetFlappingCurrent() << "%).";
+		    << "Flapping Start: Checkable '" << GetName() << "' started flapping (Current flapping value "
+		    << GetFlappingCurrent() << "% > high threshold " << GetFlappingThresholdHigh() << "%).";
 
 		NotifyFlapping(origin);
 	} else if (!in_downtime && was_flapping && !is_flapping) {
@@ -383,7 +384,8 @@ void Checkable::ProcessCheckResult(const CheckResult::Ptr& cr, const MessageOrig
 			OnNotificationsRequested(this, NotificationFlappingEnd, cr, "", "", MessageOrigin::Ptr());
 
 		Log(LogNotice, "Checkable")
-			<< "Flapping: Checkable " << GetName() << " stopped flapping (" << GetFlappingThreshold() << "% >= " << GetFlappingCurrent() << "%).";
+		    << "Flapping Stop: Checkable '" << GetName() << "' stopped flapping (Current flapping value "
+		    << GetFlappingCurrent() << "% < low threshold " << GetFlappingThresholdLow() << "%).";
 
 		NotifyFlapping(origin);
 	}
