@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -38,6 +38,10 @@ void Checkable::RemoveAllComments(void)
 void Checkable::RemoveCommentsByType(int type)
 {
 	for (const Comment::Ptr& comment : GetComments()) {
+		/* Do not remove persistent comments from an acknowledgement */
+		if (comment->GetEntryType() == CommentAcknowledgement && comment->GetPersistent())
+			continue;
+
 		if (comment->GetEntryType() == type)
 			Comment::RemoveComment(comment->GetName());
 	}
