@@ -180,10 +180,7 @@ public:
 	intrusive_ptr<EventCommand> GetEventCommand(void) const;
 
 	/* Flapping Detection */
-	double GetFlappingCurrent(void) const;
-
 	bool IsFlapping(void) const;
-	void UpdateFlappingStatus(bool stateChange);
 
 	/* Dependencies */
 	void AddDependency(const intrusive_ptr<Dependency>& dep);
@@ -239,6 +236,9 @@ private:
 	std::set<intrusive_ptr<Dependency> > m_ReverseDependencies;
 
 	void GetAllChildrenInternal(std::set<Checkable::Ptr>& children, int level = 0) const;
+
+	/* Flapping */
+	void UpdateFlappingStatus(bool stateChange);
 };
 
 }
