@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -49,7 +49,7 @@ public:
 	static int GetNextCommentID(void);
 
 	static String AddComment(const intrusive_ptr<Checkable>& checkable, CommentType entryType,
-	    const String& author, const String& text, double expireTime,
+	    const String& author, const String& text, bool persistent, double expireTime,
 	    const String& id = String(), const MessageOrigin::Ptr& origin = MessageOrigin::Ptr());
 
 	static void RemoveComment(const String& id, const MessageOrigin::Ptr& origin = MessageOrigin::Ptr());
