@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -124,6 +124,36 @@ Host::Ptr Service::GetHost(void) const
 	return m_Host;
 }
 
+/* keep in sync with Host::GetSeverity() */
+int Service::GetSeverity(void) const
+{
+	int severity = 0;
+
+	ObjectLock olock(this);
+	ServiceState state = GetStateRaw();
+
+	if (!HasBeenChecked())
+		severity |= SeverityFlagPending;
+	else if (state == ServiceWarning)
+		severity |= SeverityFlagWarning;
+	else if (state == ServiceUnknown)
+		severity |= SeverityFlagUnknown;
+	else if (state == ServiceCritical)
+		severity |= SeverityFlagCritical;
+
+	/* TODO: Add host reachability and handled */
+	if (IsInDowntime())
+		severity |= SeverityFlagDowntime;
+	else if (IsAcknowledged())
+		severity |= SeverityFlagAcknowledgement;
+	else
+		severity |= SeverityFlagUnhandled;
+
+	olock.Unlock();
+
+	return severity;
+}
+
 bool Service::IsStateOK(ServiceState state)
 {
 	return state == ServiceOK;
