@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -60,7 +60,7 @@ protected:
 	static Value NumHostsDownAccessor(const Value& row);
 	static Value NumHostsUnreachAccessor(const Value& row);
 	static Value NumServicesAccessor(const Value& row);
-	static Value WorstServicesStateAccessor(const Value& row);
+	static Value WorstServiceStateAccessor(const Value& row);
 	static Value NumServicesPendingAccessor(const Value& row);
 	static Value NumServicesOkAccessor(const Value& row);
 	static Value NumServicesWarnAccessor(const Value& row);
