@@ -233,11 +233,11 @@ Value StatusTable::CustomVariableNamesAccessor(const Value&)
 {
 	Dictionary::Ptr vars = IcingaApplication::GetInstance()->GetVars();
 
-	if (!vars)
-		return Empty;
-
 	Array::Ptr cv = new Array();
 
+	if (!vars)
+		return cv;
+
 	{
 		ObjectLock olock(vars);
 		for (const auto& kv : vars) {
@@ -252,11 +252,11 @@ Value StatusTable::CustomVariableValuesAccessor(const Value&)
 {
 	Dictionary::Ptr vars = IcingaApplication::GetInstance()->GetVars();
 
-	if (!vars)
-		return Empty;
-
 	Array::Ptr cv = new Array();
 
+	if (!vars)
+		return cv;
+
 	{
 		ObjectLock olock(vars);
 		for (const auto& kv : vars) {
@@ -271,11 +271,11 @@ Value StatusTable::CustomVariablesAccessor(const Value&)
 {
 	Dictionary::Ptr vars = IcingaApplication::GetInstance()->GetVars();
 
-	if (!vars)
-		return Empty;
-
 	Array::Ptr cv = new Array();
 
+	if (!vars)
+		return cv;
+
 	{
 		ObjectLock olock(vars);
 		for (const auto& kv : vars) {
