@@ -59,17 +59,20 @@ public:
 
 	ApiListener(void);
 
-	static ApiListener::Ptr GetInstance(void);
+	static String GetApiDir(void);
+	static String GetCertsDir(void);
+	static String GetCaDir(void);
+	static String GetCertificateRequestsDir(void);
 
-	boost::shared_ptr<SSL_CTX> GetSSLContext(void) const;
+	void UpdateSSLContext(void);
+
+	static ApiListener::Ptr GetInstance(void);
 
 	Endpoint::Ptr GetMaster(void) const;
 	bool IsMaster(void) const;
 
 	Endpoint::Ptr GetLocalEndpoint(void) const;
 
-	static String GetApiDir(void);
-
 	void SyncSendMessage(const Endpoint::Ptr& endpoint, const Dictionary::Ptr& message);
 	void RelayMessage(const MessageOrigin::Ptr& origin, const ConfigObject::Ptr& secobj, const Dictionary::Ptr& message, bool log);
 
@@ -101,6 +104,10 @@ public:
 	static bool IsHACluster(void);
 	static String GetFromZoneName(const Zone::Ptr& fromZone);
 
+	static String GetDefaultCertPath(void);
+	static String GetDefaultKeyPath(void);
+	static String GetDefaultCaPath(void);
+
 protected:
 	virtual void OnConfigLoaded(void) override;
 	virtual void OnAllConfigLoaded(void) override;
@@ -112,17 +119,23 @@ protected:
 private:
 	boost::shared_ptr<SSL_CTX> m_SSLContext;
 	std::set<TcpSocket::Ptr> m_Servers;
+
+	mutable boost::mutex m_AnonymousClientsLock;
+	mutable boost::mutex m_HttpClientsLock;
 	std::set<JsonRpcConnection::Ptr> m_AnonymousClients;
 	std::set<HttpServerConnection::Ptr> m_HttpClients;
+
 	Timer::Ptr m_Timer;
 	Timer::Ptr m_ReconnectTimer;
 	Timer::Ptr m_AuthorityTimer;
+	Timer::Ptr m_CleanupCertificateRequestsTimer;
 	Endpoint::Ptr m_LocalEndpoint;
 
 	static ApiListener::Ptr m_Instance;
 
 	void ApiTimerHandler(void);
 	void ApiReconnectTimerHandler(void);
+	void CleanupCertificateRequestsTimerHandler(void);
 
 	bool AddListener(const String& node, const String& service);
 	void AddConnection(const Endpoint::Ptr& endpoint);
@@ -148,6 +161,8 @@ private:
 	static void LogGlobHandler(std::vector<int>& files, const String& file);
 	void ReplayLog(const JsonRpcConnection::Ptr& client);
 
+	static void CopyCertificateFile(const String& oldCertPath, const String& newCertPath);
+
 	/* filesync */
 	static ConfigDirInformation LoadConfigDir(const String& dir);
 	static Dictionary::Ptr MergeConfigUpdate(const ConfigDirInformation& config);
