@@ -176,7 +176,7 @@ void ConfigPackageUtility::ActivateStage(const String& packageName, const String
 	WritePackageConfig(packageName);
 }
 
-void ConfigPackageUtility::TryActivateStageCallback(const ProcessResult& pr, const String& packageName, const String& stageName)
+void ConfigPackageUtility::TryActivateStageCallback(const ProcessResult& pr, const String& packageName, const String& stageName, bool reload)
 {
 	String logFile = GetPackageDir() + "/" + packageName + "/" + stageName + "/startup.log";
 	std::ofstream fpLog(logFile.CStr(), std::ofstream::out | std::ostream::binary | std::ostream::trunc);
@@ -190,8 +190,13 @@ void ConfigPackageUtility::TryActivateStageCallback(const ProcessResult& pr, con
 
 	/* validation went fine, activate stage and reload */
 	if (pr.ExitStatus == 0) {
-		ActivateStage(packageName, stageName);
-		Application::RequestRestart();
+		{
+			boost::mutex::scoped_lock lock(GetStaticMutex());
+			ActivateStage(packageName, stageName);
+		}
+
+		if (reload)
+			Application::RequestRestart();
 	} else {
 		Log(LogCritical, "ConfigPackageUtility")
 		    << "Config validation failed for package '"
@@ -199,7 +204,7 @@ void ConfigPackageUtility::TryActivateStageCallback(const ProcessResult& pr, con
 	}
 }
 
-void ConfigPackageUtility::AsyncTryActivateStage(const String& packageName, const String& stageName)
+void ConfigPackageUtility::AsyncTryActivateStage(const String& packageName, const String& stageName, bool reload)
 {
 	VERIFY(Application::GetArgC() >= 1);
 
@@ -213,7 +218,7 @@ void ConfigPackageUtility::AsyncTryActivateStage(const String& packageName, cons
 
 	Process::Ptr process = new Process(Process::PrepareCommand(args));
 	process->SetTimeout(300);
-	process->Run(boost::bind(&TryActivateStageCallback, _1, packageName, stageName));
+	process->Run(boost::bind(&TryActivateStageCallback, _1, packageName, stageName, reload));
 }
 
 void ConfigPackageUtility::DeleteStage(const String& packageName, const String& stageName)
@@ -315,3 +320,8 @@ bool ConfigPackageUtility::ValidateName(const String& name)
 	return (!boost::regex_search(name.GetData(), what, expr));
 }
 
+boost::mutex& ConfigPackageUtility::GetStaticMutex(void)
+{
+	static boost::mutex mutex;
+	return mutex;
+}
