@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2016 Icinga Development Team (https://www.icinga.org/)  *
+ * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -174,8 +174,12 @@ void FilterUtility::CheckPermission(const ApiUser::Ptr& user, const String& perm
 		}
 	}
 
-	if (!foundPermission)
+	if (!foundPermission) {
+		Log(LogWarning, "FilterUtility")
+		    << "Missing permission: " << requiredPermission;
+
 		BOOST_THROW_EXCEPTION(ScriptError("Missing permission: " + requiredPermission));
+	}
 }
 
 std::vector<Value> FilterUtility::GetFilterTargets(const QueryDescription& qd, const Dictionary::Ptr& query, const ApiUser::Ptr& user, const String& variableName)
