@@ -20,14 +20,14 @@ SSH="ssh $SSH_OPTIONS $user@$host"
 
 $SSH "mkdir /vagrant"
 # TODO clone git and use the icinga2x puppet modules
-git clone git://git.icinga.org/icinga-vagrant.git
+git clone git://git.icinga.com/icinga-vagrant.git
 scp -qr icinga-vagrant/icinga2x/.vagrant-puppet $user@$host:/vagrant
 rm -rf icinga-vagrant
 
 $SSH "useradd vagrant"
 $SSH "su -c 'mkdir -p -m 0700 ~/.ssh' vagrant"
 $SSH "su -c \"echo '`cat ~/.ssh/id_rsa.pub`' >> ~/.ssh/authorized_keys\" vagrant"
-$SSH "echo '10.10.27.1 packages.icinga.org' >> /etc/hosts"
+$SSH "echo '10.10.27.1 packages.icinga.com' >> /etc/hosts"
 $SSH "puppet apply --modulepath=/vagrant/.vagrant-puppet/modules" \
      "             /vagrant/.vagrant-puppet/manifests/default.pp"
 
